# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).


## [Upcoming]
## [1.1.0] - 2025-06-03
### Added
- Support for -i/--input and -o/--output options to specify input and output files.

## [1.0.2] - 2025-06-02
### Added
- URLs and topics to pyproject.toml for PyPI metadata.
- Advertise the no-dependency in the README.md.

## [1.0.1] - 2025-06-02
- Support for custom path prefix with the `--prefix` option.
## [1.0.0] - 2025-06-02
Initial release.

